@@ -39,7 +39,8 @@
 #' `show.medoids = TRUE`.
 #'
 #' @return A ggplot2 object.
-#' @import dplyr
+#' @importFrom dplyr `%>%` across all_of everything filter if_else left_join
+#'   mutate row_number summarize
 #' @importFrom rlang .data
 #'
 #' @export
@@ -134,8 +135,8 @@ ggpcp <- function(data, circ.var = NULL, is.degree = TRUE, rotate = 0,
     cluster.col <- seq_len(length(unique(clustering)))
   } else {
     if (length(cluster.col) != length(unique(clustering))) {
-      message("The number of colors does not match the number of clusters.
-            Default values will be used.")
+      message(paste("The number of colors does not match the number of",
+                    "clusters. Default values will be used."))
       cluster.col <- seq_len(length(unique(clustering)))
     }
 
@@ -143,8 +144,8 @@ ggpcp <- function(data, circ.var = NULL, is.degree = TRUE, rotate = 0,
         !identical(sort(names(cluster.col)),
                    sort(as.character(unique(clustering))))) {
       if (!is.null(names(cluster.col)))
-        message("Named \"cluster.col\" does not match cluster names. Default
-              values will be used.")
+        message(paste("Named \"cluster.col\" does not match cluster names.",
+                      "Default values will be used."))
       names(cluster.col) <- sort(unique(clustering))
     }
   }
@@ -168,8 +169,8 @@ ggpcp <- function(data, circ.var = NULL, is.degree = TRUE, rotate = 0,
   }
 
   circ_var_tbl <-
-    tibble(circ.var,
-           rotate)
+    tibble::tibble(circ.var,
+                   rotate)
 
   pcp_data <-
     data %>%
